package Embedix::DB::FileSystem;

use strict;

#_______________________________________
sub new {

}

#_______________________________________
sub DESTROY {

}

#_______________________________________
sub addDistro {

}

#_______________________________________
sub workOnDistro {

}

#_______________________________________
sub cloneDistro {

}

#_______________________________________
sub updateDistro {

}

#_______________________________________
sub getComponentList {

}

1;

__END__

=head1 NAME

Embedix::DB::FileSystem - FileSystem back-end for Embedix::DB

=head1 SYNOPSIS

instantiation

    $edb = Embedix::DB::FileSystem->new()

other examples

    ...

=head1 REQUIRES

=over 4

=item Embedix::FileSystem

=back

=head1 DESCRIPTION

a brief summary of the module written with users in mind.

=head1 METHODS

methods

=head1 CLASS VARIABLES

cvars

=head1 DIAGNOSTICS

error messages

=head1 COPYRIGHT

Copyright (c) 2000,2001 John BEPPU.  All rights reserved.  This program is
free software; you can redistribute it and/or modify it under the same
terms as Perl itself.

=head1 AUTHOR

John BEPPU <beppu@lineo.com>

=head1 SEE ALSO

=over 4

=item related perl modules

=item the latest version

=back

=cut
